@@ -10,6 +10,13 @@ test_that("neon_db", {
   db <- neon_db()
   expect_is(db, "DBIConnection")
 
+  db2 <- neon_db()
+  
+  ## Confirm cached connection
+  expect_identical(db, db2)
+  
+  neon_disconnect(db)
+  
   neon_delete_db(ask = FALSE)
   
 })
@@ -17,12 +24,14 @@ test_that("neon_db", {
 
 test_that("neon_store error handling", {
   
-  
+  expect_message({
   neon_store(table = "brd_countdata-expanded",
-            dir = tempdir())
-  
-  neon_store(product = "not-a-product",
-                   dir = tempdir())
+            dir = tempfile("no_files"))
+  })
+  expect_message({
+    neon_store(product = "not-a-product",
+                   dir = tempfile("no_products"))
+  })
 })
   
 
@@ -30,23 +39,26 @@ test_that("neon_store", {
 
   skip_if_offline()
   skip_on_cran()
+  
   dir <- tempfile()
-  db_dir <- tempfile()
   x <- neon_download(product = "DP1.10003.001",
                      site = "YELL",
                      start_date = "2018-05-01",
                      end_date = "2018-08-01", 
-                     dir = dir)
-  
-  neon_store(table = "brd_countdata-expanded", dir = dir, db_dir = db_dir)
+                     dir = dir,
+                     type = "expanded")
+  db_dir <- tempfile("database")
+  db <- neon_db(dir = db_dir, read_only = FALSE)
+  neon_store(table = "brd_countdata-expanded", dir = dir,db = db)
+
   db <- neon_db(dir = db_dir)
   expect_is(db, "DBIConnection")
   x <- DBI::dbListTables(db)
-  expect_true("brd_countdata-expanded" %in% x)
+  expect_true("brd_countdata-expanded-DP1.10003.001" %in% x)
   
   expect_true("provenance" %in% x)
   
-  tbl <- DBI::dbReadTable(db, "brd_countdata-expanded")
+  tbl <- DBI::dbReadTable(db, "brd_countdata-expanded-DP1.10003.001")
   expect_is(tbl, "data.frame")
   expect_true(nrow(tbl) > 0)
   expect_true(any(grepl("observerDistance", colnames(tbl))))
@@ -62,23 +74,26 @@ test_that("neon_table", {
   skip_on_cran()
   dir <- tempfile()
   db_dir <- tempfile()
+  db <- neon_db(dir = db_dir, read_only = FALSE)
   
   x <- neon_download(product = "DP1.10003.001",
                      site = "YELL",
                      start_date = "2018-05-01",
                      end_date = "2018-08-01",
+                     type = "expanded",
                      dir = dir)
   
   
   neon_store(table = "brd_countdata-expanded",
-             dir = dir, db_dir = db_dir)
+             dir = dir, db = db)
+  
   db <- neon_db(dir = db_dir)
   expect_is(db, "DBIConnection")
   x <- DBI::dbListTables(db)
-  expect_true("brd_countdata-expanded" %in% x)
+  expect_true("brd_countdata-expanded-DP1.10003.001" %in% x)
 
   
-  tbl <- neon_table("brd_countdata-expanded", db = db)
+  tbl <- neon_table("brd_countdata", db = db)
   expect_is(tbl, "data.frame")
   expect_true(nrow(tbl) > 0)
   expect_true(any(grepl("observerDistance", colnames(tbl))))
